@@ -1,5 +1,5 @@
 package Beam::Runnable;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 # ABSTRACT: Role for runnable objects
 
 #pod =head1 SYNOPSIS
@@ -34,7 +34,8 @@ our $VERSION = '0.007';
 #pod L<Pod::Usage> produces by default.
 #pod
 #pod The C<beam list> command, when listing runnable objects, will display
-#pod the C<NAME> (abstract) next to the service name.
+#pod either the C<summary> attribute or the C<NAME> POD section (abstract)
+#pod next to the service name.
 #pod
 #pod =head1 SEE ALSO
 #pod
@@ -45,6 +46,20 @@ our $VERSION = '0.007';
 use strict;
 use warnings;
 use Moo::Role;
+with 'Beam::Service';
+use Types::Standard qw( Str );
+
+#pod =attr summary
+#pod
+#pod A summary of the task to be run. This will be displayed by the C<beam
+#pod list> command in the list.
+#pod
+#pod =cut
+
+has summary => (
+    is => 'ro',
+    isa => Str,
+);
 
 #pod =method run
 #pod
@@ -71,7 +86,7 @@ Beam::Runnable - Role for runnable objects
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -105,7 +120,15 @@ C<OPTIONS>, and C<SEE ALSO> sections. This is the same as what
 L<Pod::Usage> produces by default.
 
 The C<beam list> command, when listing runnable objects, will display
-the C<NAME> (abstract) next to the service name.
+either the C<summary> attribute or the C<NAME> POD section (abstract)
+next to the service name.
+
+=head1 ATTRIBUTES
+
+=head2 summary
+
+A summary of the task to be run. This will be displayed by the C<beam
+list> command in the list.
 
 =head1 METHODS
 
