@@ -1,5 +1,5 @@
 package Beam::Runner::Command::run;
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 # ABSTRACT: Run the given service with the given arguments
 
 #pod =head1 SYNOPSIS
@@ -32,11 +32,11 @@ sub run {
 
     my $service = eval { $wire->get( $service_name ) };
     if ( $@ ) {
-        if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::NotFound' ) ) {
+        if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::NotFound' ) && $@->name eq $service_name ) {
             die sprintf qq{Could not find service "%s" in container "%s"\n},
                 $service_name, $path;
         }
-        die $@;
+        die sprintf qq{Could not load service "%s" in container "%s": %s\n}, $service_name, $path, $@;
     }
 
     return $service->run( @args );
@@ -54,7 +54,7 @@ Beam::Runner::Command::run - Run the given service with the given arguments
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
